@@ -16,7 +16,7 @@ class AccountBasedExpenseLineDetail(QuickbooksBaseObject):
 
     def __init__(self):
         super(AccountBasedExpenseLineDetail, self).__init__()
-        self.BillableStatus = ""
+        self.BillableStatus = None
         self.TaxAmount = 0
         self.TaxInclusiveAmt = 0
 
@@ -98,7 +98,6 @@ class Bill(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin)
 
     list_dict = {
         "Line": BillLine,
-        "LinkedTxn": LinkedTxn
     }
 
     qbo_object_name = "Bill"
@@ -113,7 +112,7 @@ class Bill(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin)
         self.DocNumber = ""
         self.PrivateNote = ""
         self.ExchangeRate = 0
-        self.GlobalTaxCalculation = ""
+        self.GlobalTaxCalculation = None
 
         self.SalesTermRef = None
         self.CurrencyRef = None
@@ -127,3 +126,11 @@ class Bill(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin)
 
     def __str__(self):
         return str(self.Balance)
+
+    def to_linked_txn(self):
+        linked_txn = LinkedTxn()
+        linked_txn.TxnId = self.Id
+        linked_txn.TxnType = "Bill"
+        linked_txn.TxnLineId = 1
+
+        return linked_txn
